// $Id: UpdatePositionCmd.cpp 84578 2009-02-23 16:07:12Z johnnyw $

#include "RootPanel.h"
#include "UpdatePositionCmd.h"
#include <Qt/qlcdnumber.h>
#include "NavUnit.h"


UpdatePositionCmd::UpdatePositionCmd()
{
}


UpdatePositionCmd *
UpdatePositionCmd::create(
  RootPanel *form, NavUnit *unit)
{
  UpdatePositionCmd *cmd = new UpdatePositionCmd();
  cmd->form_ = form;
  cmd->unit_ = unit;
  return cmd;
}


int
UpdatePositionCmd::execute (void * /* context */)
{
  this->form_->updateUnit (this->unit_);
  return 0;
}
